@@ -4,11 +4,10 @@ import requests
 
 
 class Newton:
-    def __init__(self, api_url, api_key):
-        self.api_base = "https://api.objectways.com/v1"
+    def __init__(self, api_key, api_url="https://api.objectways.com/v1"):
+        #self.api_base = "https://api.objectways.com/v1"
 
-        if api_url is not None:
-            self.api_base = api_url
+        self.api_base = api_url
 
         self.__headers = {"Content-Type": "application/json", "api_key": api_key}
 
